import { BaseEntity, BeforeInsert, BeforeUpdate, Column, PrimaryGeneratedColumn } from 'typeorm';

export abstract class CommonEntity extends BaseEntity {
  @Column({
    type: 'double precision',
    default: 1,
  })
  created_at: number;

  @Column({
    type: 'double precision',
    default: 1,
  })
  updated_at: number;

  @PrimaryGeneratedColumn('identity', {
    type: 'bigint',
  })
  id: string;

  @BeforeInsert()
  protected insertDates() {
    const unix_timestamp = performance.timeOrigin;

    this.created_at = unix_timestamp;
    this.updated_at = unix_timestamp;
  }

  @BeforeUpdate()
  protected updateDates() {
    const unix_timestamp = performance.timeOrigin;

    this.updated_at = unix_timestamp;
  }
}
